@@ -349,6 +349,7 @@ void open_recent_file (GtkWidget *DummyWidget, gchar *FileName)
   FPROPS(CurrentPage, Changed[1]) =
     gtk_signal_connect (GTK_OBJECT(FPROPS(CurrentPage, Text)), "changed",
 			(GtkSignalFunc) set_changed, NULL);
+  (void)DummyWidget; /* avoid the "unused parameter" warning */
 }
 
 
@@ -458,7 +459,7 @@ void save_file_as_func (GtkFileSelection *FileSelector)
 	gtk_signal_disconnect (GTK_OBJECT(FPROPS(CurrentPage, Text)),
 			       FPROPS(CurrentPage, Changed[1]));
       init_file_properties (FileName, CurrentPage);
-      reopen_file_in_editor (FPROPS(CurrentPage, Text), FileName);
+      refresh_editor(FPROPS(CurrentPage, Text), SYHI_AUTODETECT);
       FPROPS(CurrentPage, Changed[1]) = gtk_signal_connect
 	(GTK_OBJECT(CurrentText), "changed", (GtkSignalFunc)set_changed, NULL);
       set_label (GTK_NOTEBOOK(MainNotebook), CurrentPage);
@@ -742,6 +743,7 @@ void close_file_func (GtkWidget *Widget, gint CurrentPage)
       set_title (GTK_NOTEBOOK(MainNotebook), NULL, -1);
       NewFilesCnt = 0;
     }
+  (void)Widget; /* avoid the "unused parameter" warning */
 }
 
 
