@@ -79,6 +79,7 @@ t_search_results *find (gint page,
   gint len, i, j, k = 1, line_nb = 1;
   t_search_results *res;
 
+  (void)reg_exp; /* regular expressions are not yet implemented */
   res = g_malloc (sizeof(t_search_results));
   len = strlen (string);
   buffer = gtk_editable_get_chars
@@ -121,6 +122,7 @@ gint replace_all (gint page,
   gint len_in, len_out, string_in_len, string_out_len;
   gint i, j, k, rep_nb = 0;
   
+  (void)reg_exp; /* regular expressions are not yet implemented */
   buffer_in = gtk_editable_get_chars
     (GTK_EDITABLE(FPROPS(page, Text)), 0, -1);
   len_in = strlen (buffer_in);
@@ -182,7 +184,7 @@ void goto_search (GtkList *MyList,
 
       gtk_label_get (GTK_LABEL(GTK_BIN(Widget) -> child), &string);
       sscanf (string, "%*d. Line %d (%d-%d)", &Line, &Begin, &End);
-      if (End <= gtk_text_get_length (GTK_TEXT(FPROPS(CurrentPage, Text))))
+      if (End <= (gint)gtk_text_get_length(GTK_TEXT(FPROPS(CurrentPage, Text))))
 	{
 	  gtk_editable_set_position (GTK_EDITABLE(FPROPS(CurrentPage, Text)),
 				     Begin);
@@ -219,6 +221,7 @@ void goto_search (GtkList *MyList,
     }
   else
     print_msg ("The Current Search wasn't done on this file...");
+  (void)MyList; /* avoid the "unused parameter" warning */
 }
 
 
@@ -243,13 +246,14 @@ void refresh_search (GtkWidget *Widget, gchar *Data)
       else
 	SearchPrefs -> CaseSen = FALSE;
     }
-  else if (!strcmp (Data, "reg_exp"))
+/* TODO: implement the regexp feature */
+/*  else if (!strcmp (Data, "reg_exp"))
     {
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(Widget)))
 	SearchPrefs -> RegExp = TRUE;
       else
 	SearchPrefs -> RegExp = FALSE;
-    }
+    } */
   else if (!strcmp (Data, "search"))
     {
       gchar *msg;
@@ -494,10 +498,11 @@ void search (gboolean Replace)
   gtk_signal_connect (GTK_OBJECT(Button), "toggled",
 		      (GtkSignalFunc)refresh_search, "case_sen"); 
   gtk_box_pack_start (GTK_BOX(VBox2), Button, FALSE, FALSE, 0);
-  Button = gtk_check_button_new_with_label ("Regular expression search");
+/* TODO: implement the regexp feature */
+/*  Button = gtk_check_button_new_with_label ("Regular expression search");
   gtk_signal_connect (GTK_OBJECT(Button), "toggled",
 		      (GtkSignalFunc)refresh_search, "reg_exp"); 
-  gtk_box_pack_start (GTK_BOX(VBox2), Button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(VBox2), Button, FALSE, FALSE, 0); */
   if (Replace)
     {
       Frame = gtk_frame_new ("Replace");
