@@ -281,6 +281,7 @@ void refresh_converter (GtkWidget *Widget, gint EntryID)
     }
   else
     gtk_entry_set_text (GTK_ENTRY (Entry[1]), "0");
+  (void)Widget; /* avoid the "unused parameter" warning */
 }
 
 
@@ -457,6 +458,21 @@ gint replace_char (char *string, char to_replace, char new_char)
 
 /* File conversion functions */
 
+void convert_all(void (*conv_func)(void))
+{
+  gint CurrentPage, i;
+
+  if (!OpenedFilesCnt) return;
+  CurrentPage = gtk_notebook_get_current_page (GTK_NOTEBOOK(MainNotebook));
+  for (i = 0; i < OpenedFilesCnt; i++)
+    if (!FPROPS(CurrentPage, ReadOnly))
+      {
+	gtk_notebook_set_page (GTK_NOTEBOOK(MainNotebook), i);
+	conv_func ();
+      }
+  gtk_notebook_set_page (GTK_NOTEBOOK(MainNotebook), CurrentPage);
+}
+
 void conv_unix_to_dos (void)
 {
   gint CurrentPage, res;
